@@ -1,3 +1,4 @@
+import re
 
 
 def get_upper_camel_case(snake_case_name):
@@ -5,6 +6,13 @@ def get_upper_camel_case(snake_case_name):
     return ''.join([nb.capitalize() for nb in snake_case_name.split('_')])
 
 
+def get_snake_case(upper_camel_case):
+    # https://stackoverflow.com/questions/1175208/elegant-python-function-to-convert-camelcase-to-snake-case
+    snake_name = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', upper_camel_case)
+    snake_name = re.sub('([a-z0-9])([A-Z])', r'\1_\2', snake_name).lower()
+    return snake_name
+
+
 def get_funcx_flow_state_name(funcx_function):
     """State names in Automate are typically upper camel case. This function generates
     an upper case funcx function name for flow states."""
